@@ -1,6 +1,7 @@
 from .config import init_config, config
 from .utils import *
-from .log_id import release_logid, get_logid
+from .log_id import release_logid, get_logid, set_logid
 from .log import *
 from .wrapper import try_catch_exception, catch_raise_exception
 from .rabbitmq import RabbitmqClient
+from .message import send_mail, send_sms, try_send_mail
