@@ -13,6 +13,8 @@ def init_apollo_config(app_id, cluster_name, config_server_url, hot_load=False):
 
 
 def appllo_config(namespace=None, key=None, default_value=None):
+    if not __apollo_client:
+        return default_value
     if not key:
         key = namespace
         namespace = 'application'
