@@ -31,8 +31,27 @@ def set_log_callback(log_callback):
     __log_callback = log_callback
 
 
-def _get_config(root_path='.', is_console=True, module_name='', split_error_log=False):
+def _get_handler_class_config(use_rotate):
+    if use_rotate:
+        return {
+            'class': 'logging.handlers.TimedRotatingFileHandler',
+            'when': 'midnight',
+            'backupCount': int(config('logging.handler.backup_count', default_value=3))
+        }
+    return {
+        'class': 'logging.FileHandler'
+    }
+
+
+def _get_config(root_path='.', is_console=True, module_name='', split_error_log=False, use_rotate=True):
     global __is_debug, __log_name
+    info_handler = {
+        'level': 'DEBUG',
+        'filename': _get_file_path(root_path, module_name),
+        'encoding': 'utf8',
+        'formatter': 'verbose',
+    }
+    info_handler.update(_get_handler_class_config(use_rotate))
     config_dict = {
         'version': 1,
         'disable_existing_loggers': False,
@@ -43,28 +62,19 @@ def _get_config(root_path='.', is_console=True, module_name='', split_error_log=
             },
         },
         'handlers': {
-            'info': {
-                'level': 'DEBUG',
-                'class': 'logging.handlers.TimedRotatingFileHandler',
-                'filename': _get_file_path(root_path, module_name),
-                'encoding': 'utf8',
-                'formatter': 'verbose',
-                'when': 'midnight',
-                'backupCount': int(config('logging.handler.backup_count', default_value=3))
-            }
+            'info': info_handler
         }
     }
     handlers = ['info']
     if split_error_log:
-        config_dict['handlers']['error'] = {
+        error_handler = {
             'level': 'ERROR',
-            'class': 'logging.handlers.TimedRotatingFileHandler',
             'filename': _get_file_path(root_path, module_name + '.error'),
             'encoding': 'utf8',
             'formatter': 'verbose',
-            'when': 'midnight',
-            'backupCount': int(config('logging.handler.backup_count', default_value=3))
         }
+        error_handler.update(_get_handler_class_config(use_rotate))
+        config_dict['handlers']['error'] = error_handler
         handlers = ['error', 'info']
     config_dict['root'] = {
         'handlers': handlers,
@@ -85,7 +95,7 @@ def _get_config(root_path='.', is_console=True, module_name='', split_error_log=
     return config_dict
 
 
-def log_init_config(root_path, module_name, is_debug=None, split_error_log=False):
+def log_init_config(root_path, module_name, is_debug=None, split_error_log=False, use_rotate=True):
     global __logger, __module_name, __is_debug, __split_error_log, _log_config
     if is_debug is None:
         try:
@@ -96,7 +106,7 @@ def log_init_config(root_path, module_name, is_debug=None, split_error_log=False
         __is_debug = is_debug
     __module_name = module_name
     __split_error_log = split_error_log
-    _log_config = _get_config(root_path, root_path == 'console', module_name, split_error_log)
+    _log_config = _get_config(root_path, root_path == 'console', module_name, split_error_log, use_rotate)
     logging.config.dictConfig(_log_config)
     __logger = logging.getLogger(__log_name)
     if not __is_debug:
@@ -179,6 +189,7 @@ def _callback_log_message(log_level, msg):
         except Exception as ex:
             pass
 
+
 def raise_error_exception(message):
     log_error(message)
     raise Exception(message)
