@@ -1,3 +1,5 @@
+import sys
+sys.path.append('.')
 from libra_core.config import *
 from libra_core.utils import sleep
 
@@ -27,3 +29,7 @@ def test_another_config():
     print(config("property_a"))
     init_config()
     print(config("property_a"))
+
+
+if __name__ == "__main__":
+    test_apollo_config()
